@@ -36,3 +36,22 @@ test_that("plot.twsa returns a ggplot object", {
   g <- plot(t)
   expect_is(g, "ggplot")
 })
+
+
+# test basecase argument for plot.twsa
+test_that("plot.twsa basecase argument", {
+  t <- twsa(psa_big, "pFailChemo", "muDieCancer", outcome = "eff")
+  g <- plot(t,
+            basecase = list(pFailChemo = 0.37, muDieCancer = 0.09))
+  expect_is(g, "ggplot")
+
+  t2 <- twsa(psa_big, "pFailChemo", "muDieCancer", outcome = "eff")
+  g2 <- plot(t,
+             basecase = list(muDieCancer = 0.09, pFailChemo = 0.37))
+  expect_is(g2, "ggplot")
+
+  # test error when wrong parameter is supplied
+  expect_error(plot(t,
+                    basecase = list(pFailChemo = 0.37, non_existent = .050)),
+               "Some parameter names in the basecase argument do not match param1 or param2 of twsa")
+})
